(window["webpackJsonp"]=window["webpackJsonp"]||[]).push([["chunk-2d0ae589"],{"0a57":function(e,n,i){"use strict";i.r(n),i.d(n,"menu",function(){return t}),i.d(n,"isFolder",function(){return d}),i.d(n,"showContentMenu",function(){return r}),i.d(n,"hideContentMenu",function(){return o});var t={file:[{text:"Run 运行",code:"run"},{isdivider:!0},{text:"Rename 重命名",code:"rename"},{isdivider:!0},{text:"Delete 删除",code:"deleteFile"},{isdivider:!0}],folder:[{text:"Refresh 刷新",code:"refresh"},{isdivider:!0},{text:"Rename 重命名",code:"rename"},{isdivider:!0},{text:"New File 新建文件",code:"newFile"},{isdivider:!0},{text:"New Folder 新建文件夹",code:"newFolder"},{isdivider:!0},{text:"Delete 删除文件夹",code:"deleteFolder"}]};function d(e){return"children"in e}function r(e,n){var i={left:n.clientX,top:n.clientY};e.show(i)}function o(e){e.hide()}}}]);
//# sourceMappingURL=chunk-2d0ae589.7cd8488a.js.map