(window["webpackJsonp"]=window["webpackJsonp"]||[]).push([["chunk-2d0b6d28"],{"1f96":function(e,t,i){"use strict";i.r(t);var n={methods:{SIGNAL_PUT_FILE:function(e){var t=arguments.length>1&&void 0!==arguments[1]?arguments[1]:"cli",i=arguments.length>2&&void 0!==arguments[2]?arguments[2]:"slotPutFile";return{event:"putFile",sender:e,receiver:t,slot:i,kwargs:{filename:this.putFilename[this.index],fileData:this.putFileData[this.index]}}}}};t["default"]=n}}]);
//# sourceMappingURL=chunk-2d0b6d28.bd864b37.js.map