.ide-bottom-bar[data-v-3f09efd1]{width:100vw;height:3vh;padding-right:16px;color:#fff}.ide-bottom-bar-left[data-v-3f09efd1]{width:95vw;padding-left:8px}.ide-bottom-bar-right[data-v-3f09efd1]{width:5vw}.info[data-v-3f09efd1]{padding:auto 0;margin-left:12px;font-size:16px;color:#fff}