(window["webpackJsonp"]=window["webpackJsonp"]||[]).push([["chunk-2d0d3720"],{"5d94":function(e,r,n){"use strict";n.r(r);var o=function(){var e=this,r=e.$createElement,n=e._self._c||r;return n("div",[e._v("\n  ERROR: "+e._s(e.errorCode)+"\n")])},t=[],u={name:"error",computed:{errorCode:function(){return this.$route.meta.errorCode||"404"}}},c=u,d=n("048f"),i=Object(d["a"])(c,o,t,!1,null,null,null);i.options.__file="error.vue";r["default"]=i.exports}}]);
//# sourceMappingURL=chunk-2d0d3720.ce5217b2.js.map