(window["webpackJsonp"]=window["webpackJsonp"]||[]).push([["chunk-2d0e64c6"],{"97c5":function(n,a,c){"use strict";c.r(a);var s={data:function(){return{isParent:!0,signals:null}}};a["default"]=s}}]);
//# sourceMappingURL=chunk-2d0e64c6.948e8e65.js.map