(window["webpackJsonp"]=window["webpackJsonp"]||[]).push([["chunk-6f2a5820","chunk-6146d972","chunk-83c74884","chunk-2d0d6b33","chunk-2d0cf123","chunk-2d0bdcd1"],{"0bf2":function(t,e,n){"use strict";var i=n("682a"),o=n.n(i);o.a},"158a":function(t,e,n){"use strict";n.r(e);n("cf54");var i={watch:{listener:function(){if(this.signals.ref===this.$options.name)try{this[this.signals.slot](this.signals.kwargs)}catch(t){console.log(t)}}}};e["default"]=i},2957:function(t,e,n){"use strict";n.r(e);var i=function(){var t=this,e=t.$createElement,n=t._self._c||e;return n("div",[n("mu-dialog",{attrs:{title:"EMP IDE configs",width:"400","max-width":"80%","esc-press-close":!1,"overlay-close":!1,open:t.show},on:{"update:open":function(e){t.show=e}}},[n("mu-flex",{attrs:{direction:"column"}},[n("mu-text-field",{attrs:{label:"Editor fontsize",color:"primary","full-width":""},model:{value:t.fontSize,callback:function(e){t.fontSize=e},expression:"fontSize"}}),n("mu-text-field",{attrs:{label:"Memory limit",color:"primary","full-width":"",disabled:""}})],1),n("mu-button",{attrs:{slot:"actions",flat:"",color:"primary"},on:{click:t.apply},slot:"actions"},[t._v("Apply")]),n("mu-button",{attrs:{slot:"actions",flat:"",color:"primary"},on:{click:t.esc},slot:"actions"},[t._v("ESC")])],1)],1)},o=[],s=n("7455"),c=n("61c5"),r=n("2e19"),l=n("158a"),a={name:"setting",mixins:[s["default"],c["default"],r["default"],l["default"]],props:["show"],data:function(){return{fontSize:16,buttonText:"connect",webSocketStatus:!1}},mounted:function(){this.$nextTick(function(){this.getCookies()})},methods:{apply:function(){this.setCookies(),this.$send(this.SIGNAL_TOGGLE_SETTINGS(this)),this.$send(this.SIGNAL_APPLY_FONTSIZE(this))},esc:function(){this.setCookies(),this.$send(this.SIGNAL_TOGGLE_SETTINGS(this))},getCookies:function(){null!=this.$cookie.get("fontSize")&&(this.fontSize=parseInt(this.$cookie.get("fontSize")))},setCookies:function(){this.$cookie.set("fontSize",this.fontSize,{expires:"1Y"})}}},u=a,f=(n("0bf2"),n("048f")),h=Object(f["a"])(u,i,o,!1,null,"189aa038",null);h.options.__file="Setting.vue";e["default"]=h.exports},"2e19":function(t,e,n){"use strict";n.r(e);var i={props:["listener"]};e["default"]=i},5332:function(t,e,n){"use strict";n.r(e);var i=n("2957");e["default"]=i["default"]},"61c5":function(t,e,n){"use strict";n.r(e);var i={methods:{slotConnected:function(){this.buttonText="Disconnect",this.webSocketStatus=!0},slotDisconnect:function(){this.buttonText="Connect",this.webSocketStatus=!1}}};e["default"]=i},"682a":function(t,e,n){},7455:function(t,e,n){"use strict";n.r(e);var i={methods:{SIGNAL_CONNECT_TO_DEVICE:function(t){var e=arguments.length>1&&void 0!==arguments[1]?arguments[1]:"cli",n=arguments.length>2&&void 0!==arguments[2]?arguments[2]:"slotConnectToDevice";return{event:"connectToDevice",sender:t,receiver:e,slot:n,kwargs:{url:this.url,passwd:this.passwd}}},SIGNAL_DISCONNECT:function(t){var e=arguments.length>1&&void 0!==arguments[1]?arguments[1]:"cli",n=arguments.length>2&&void 0!==arguments[2]?arguments[2]:"slotDisconnect";return{event:"disconnect",sender:t,receiver:e,slot:n,kwargs:{}}},SIGNAL_TOGGLE_SETTINGS:function(t){var e=arguments.length>1&&void 0!==arguments[1]?arguments[1]:"parent",n=arguments.length>2&&void 0!==arguments[2]?arguments[2]:"slotToggleSettings";return{event:"toggleSettings",sender:t,receiver:e,slot:n,kwargs:{}}},SIGNAL_APPLY_FONTSIZE:function(t){var e=arguments.length>1&&void 0!==arguments[1]?arguments[1]:"editor",n=arguments.length>2&&void 0!==arguments[2]?arguments[2]:"slotApplyFontSize";return{event:"applyFontSize",sender:t,receiver:e,slot:n,kwargs:{fontSize:this.fontSize}}}}};e["default"]=i},cf54:function(t,e,n){var i=n("9a0d").f,o=Function.prototype,s=/^\s*function ([^ (]*)/,c="name";c in o||n("f711")&&i(o,c,{configurable:!0,get:function(){try{return(""+this).match(s)[1]}catch(t){return""}}})}}]);
//# sourceMappingURL=chunk-6f2a5820.e97ff0be.js.map