(window["webpackJsonp"]=window["webpackJsonp"]||[]).push([["chunk-2d0e4a7b"],{"90c1":function(e,t,n){"use strict";n.r(t);var o={methods:{SIGNAL_OPENSET:function(e){var t=arguments.length>1&&void 0!==arguments[1]?arguments[1]:"parent",n=arguments.length>2&&void 0!==arguments[2]?arguments[2]:"slotToggleSettings";return{event:"openset",sender:e,receiver:t,slot:n,kwargs:{show:this.showSetting}}},SIGNAL_TOGGLE_TERM:function(e){var t=arguments.length>1&&void 0!==arguments[1]?arguments[1]:"splitHorizontal",n=arguments.length>2&&void 0!==arguments[2]?arguments[2]:"slotToggleTerm";return{event:"toggleTerm",sender:e,receiver:t,slot:n,kwargs:{}}}}};t["default"]=o}}]);
//# sourceMappingURL=chunk-2d0e4a7b.e6023d22.js.map