(window["webpackJsonp"]=window["webpackJsonp"]||[]).push([["chunk-2d221834"],{cb54:function(s,e,t){"use strict";t.r(e);var i={methods:{slotUpdateFiles:function(s){this.files=this.traverse(s.files)}}};e["default"]=i}}]);
//# sourceMappingURL=chunk-2d221834.19276a1e.js.map