(window["webpackJsonp"]=window["webpackJsonp"]||[]).push([["chunk-2d0d0446"],{"66f6":function(t,e,i){"use strict";i.r(e);var o={methods:{slotResizeEditor:function(){this.$refs["editor"].layout()},slotShowCode:function(t){var e=this;this.code=t.code,this.openedFile=t.filename,this.$send(this.SIGNAL_UNLOCK(this)),setTimeout(function(){return e.$send(e.SIGNAL_CLEAR_TERM(e))},300)},slotApplyFontSize:function(t){var e=parseInt(t.fontSize);isNaN(e)||(this.fontSize=e)}}};e["default"]=o}}]);
//# sourceMappingURL=chunk-2d0d0446.f3f6d505.js.map