(window["webpackJsonp"]=window["webpackJsonp"]||[]).push([["chunk-2d0c0e14"],{4453:function(e,r,n){"use strict";n.r(r);var t={methods:{SIGNAL_CLEAR:function(e){var r=arguments.length>1&&void 0!==arguments[1]?arguments[1]:"cli",n=arguments.length>2&&void 0!==arguments[2]?arguments[2]:"slotClearTerm";return{event:"clearTerm",sender:e,receiver:r,slot:n,kwargs:{}}},SIGNAL_RESIZE_TERM:function(e){var r=arguments.length>1&&void 0!==arguments[1]?arguments[1]:"cli",n=arguments.length>2&&void 0!==arguments[2]?arguments[2]:"slotResizeTerm";return{event:"onResize",sender:e,receiver:r,slot:n,kwargs:{}}},SIGNAL_RESIZE_EDITOR:function(e){var r=arguments.length>1&&void 0!==arguments[1]?arguments[1]:"editor",n=arguments.length>2&&void 0!==arguments[2]?arguments[2]:"slotResizeEditor";return{event:"onResize",sender:e,receiver:r,slot:n,kwargs:{}}}}};r["default"]=t}}]);
//# sourceMappingURL=chunk-2d0c0e14.acc4673f.js.map