(window["webpackJsonp"]=window["webpackJsonp"]||[]).push([["chunk-2d0e235d"],{"7e70":function(_,e,o){"use strict";o.r(e),e["default"]="\n     _____  __  __  ____    ___  ____   _____\n    | ____||  \\/  ||  _ \\  |_ _||  _ \\ | ____|\n    |  _|  | |\\/| || |_) |  | | | | | ||  _|\n    | |___ | |  | ||  __/   | | | |_| || |___\n    |_____||_|  |_||_|     |___||____/ |_____|\n\n    Easy MicroPython (EMP) is an open source project led by 1ZLAB \n    to provide a faster and more efficient development experience \n    for MicroPython enthusiasts.\n\n    GitHub:   https://github.com/Fuermohao/EMP-IDE\n    HomePage: http://www.1zlab.com\n    Docs:     http://www.1zlab.com/doc/emp\n\n    Before you start using it, you need to use the upip to install \n    the emp-1zlab module on your MicroPython device. Please follow \n    the instructions below:\n\n    import upip\n    upip.install('emp-1zlab')\n\n    import emp_boot\n    emp_boot.set_boot_mode()\n\n    Enter 2, This operation will overwrite your boot.py file, and your \n    device will restart. Please follow the prompts to connect to wifi \n    after rebooting. After that, webrepl will be automatically enabled. \n    The default password is '1zlab', you can modify it in webrepl.pass.\n"}}]);
//# sourceMappingURL=chunk-2d0e235d.0e267c38.js.map