(window["webpackJsonp"]=window["webpackJsonp"]||[]).push([["chunk-2d0cf123"],{"61c5":function(t,n,o){"use strict";o.r(n);var c={methods:{slotConnected:function(){this.buttonText="Disconnect",this.webSocketStatus=!0},slotDisconnect:function(){this.buttonText="Connect",this.webSocketStatus=!1}}};n["default"]=c}}]);
//# sourceMappingURL=chunk-2d0cf123.4a1bea35.js.map