<!DOCTYPE html><html><head><meta charset=utf-8><meta name=viewport content="width=device-width,initial-scale=1"><meta name=description content="1ZLAB EMP-IDE是1Z实验室为广大MicroPython ESP32/ESP8266爱好者所开发的一款微型Web集成开发环境,旨在提高开发效率和开发体验"><meta name=keywords content=EMP-IDE,1ZLAB,1Z实验室,MicroPython,MicroPythonIDE,ESP32,ESP8266,webrepl,成都码立方科技><link rel="shortcut icon" href=http://src.1zlab.com/1zlab-logo-transparent.png><link rel=stylesheet href=https://unpkg.com/muse-ui/dist/muse-ui.css><script src=https://cdn.jsdelivr.net/npm/vue@2.5.17/dist/vue.js></script><script src=https://unpkg.com/muse-ui/dist/muse-ui.js></script><title>EMP-IDE</title><style>body {
      overflow-x: hidden;
      overflow-y: hidden;
      height: 100%;
      width: 100%;
      background: #1e1e1e;
    }</style><script async src="https://www.googletagmanager.com/gtag/js?id=UA-127068587-1"></script><script>window.dataLayer = window.dataLayer || [];

    function gtag() {
      dataLayer.push(arguments);
    }

    gtag('js', new Date());

    gtag('config', 'UA-127068587-1');</script><link href="{{ url_for('static', filename='css/chunk-0647d7dc.0b9dbeff.css') }}" rel=prefetch><link href="{{ url_for('static', filename='css/chunk-105ecf8e.94d8ee91.css') }}" rel=prefetch><link href="{{ url_for('static', filename='css/chunk-152aa660.e5ff0d51.css') }}" rel=prefetch><link href="{{ url_for('static', filename='css/chunk-2ac974e4.9fcb523d.css') }}" rel=prefetch><link href="{{ url_for('static', filename='css/chunk-324a8daa.42c093fa.css') }}" rel=prefetch><link href="{{ url_for('static', filename='css/chunk-3ef5cf24.7df6edf9.css') }}" rel=prefetch><link href="{{ url_for('static', filename='css/chunk-5343f65a.42c093fa.css') }}" rel=prefetch><link href="{{ url_for('static', filename='css/chunk-5cf56edd.1ab62ebb.css') }}" rel=prefetch><link href="{{ url_for('static', filename='css/chunk-5f5b5007.7feb5007.css') }}" rel=prefetch><link href="{{ url_for('static', filename='css/chunk-6146d972.d06980e6.css') }}" rel=prefetch><link href="{{ url_for('static', filename='css/chunk-66551290.0b9dbeff.css') }}" rel=prefetch><link href="{{ url_for('static', filename='css/chunk-6f24c2c8.fcc41532.css') }}" rel=prefetch><link href="{{ url_for('static', filename='css/chunk-6f2a5820.d06980e6.css') }}" rel=prefetch><link href="{{ url_for('static', filename='css/chunk-707eb013.1ab62ebb.css') }}" rel=prefetch><link href="{{ url_for('static', filename='css/chunk-a6604a3e.91ac850b.css') }}" rel=prefetch><link href="{{ url_for('static', filename='css/chunk-ab01839c.fcc41532.css') }}" rel=prefetch><link href="{{ url_for('static', filename='css/chunk-abafcd8e.91ac850b.css') }}" rel=prefetch><link href="{{ url_for('static', filename='css/chunk-b441fb64.25d54002.css') }}" rel=prefetch><link href="{{ url_for('static', filename='css/chunk-ba7886f2.b43f01ff.css') }}" rel=prefetch><link href="{{ url_for('static', filename='css/chunk-cb1baf7a.7feb5007.css') }}" rel=prefetch><link href="{{ url_for('static', filename='css/chunk-cbe61776.7ccac7b3.css') }}" rel=prefetch><link href="{{ url_for('static', filename='css/chunk-d8fb7f32.6d04e539.css') }}" rel=prefetch><link href="{{ url_for('static', filename='css/chunk-e6edb01a.701f32e3.css') }}" rel=prefetch><link href="{{ url_for('static', filename='css/chunk-fedbce3e.701f32e3.css') }}" rel=prefetch><link href="{{ url_for('static', filename='js/chunk-0647d7dc.715b5f52.js') }}" rel=prefetch><link href="{{ url_for('static', filename='js/chunk-075166f1.3c172f89.js') }}" rel=prefetch><link href="{{ url_for('static', filename='js/chunk-105ecf8e.fa3608a6.js') }}" rel=prefetch><link href="{{ url_for('static', filename='js/chunk-152aa660.cde7c6da.js') }}" rel=prefetch><link href="{{ url_for('static', filename='js/chunk-1e61c374.9b4cc142.js') }}" rel=prefetch><link href="{{ url_for('static', filename='js/chunk-2ac974e4.2bb7fd7c.js') }}" rel=prefetch><link href="{{ url_for('static', filename='js/chunk-2d0a402c.87fec7c7.js') }}" rel=prefetch><link href="{{ url_for('static', filename='js/chunk-2d0a4745.2e2ba8d9.js') }}" rel=prefetch><link href="{{ url_for('static', filename='js/chunk-2d0ab0c9.fa94fba3.js') }}" rel=prefetch><link href="{{ url_for('static', filename='js/chunk-2d0abbfd.30910c2c.js') }}" rel=prefetch><link href="{{ url_for('static', filename='js/chunk-2d0ae57a.d2e4aa08.js') }}" rel=prefetch><link href="{{ url_for('static', filename='js/chunk-2d0ae589.7cd8488a.js') }}" rel=prefetch><link href="{{ url_for('static', filename='js/chunk-2d0af04a.e7ace5dc.js') }}" rel=prefetch><link href="{{ url_for('static', filename='js/chunk-2d0af25f.eb897f00.js') }}" rel=prefetch><link href="{{ url_for('static', filename='js/chunk-2d0b59c3.63610002.js') }}" rel=prefetch><link href="{{ url_for('static', filename='js/chunk-2d0b6d28.bd864b37.js') }}" rel=prefetch><link href="{{ url_for('static', filename='js/chunk-2d0b9420.0cb4b36b.js') }}" rel=prefetch><link href="{{ url_for('static', filename='js/chunk-2d0b9ba8.c347971f.js') }}" rel=prefetch><link href="{{ url_for('static', filename='js/chunk-2d0ba189.075c9cd8.js') }}" rel=prefetch><link href="{{ url_for('static', filename='js/chunk-2d0bd3c7.a18923cf.js') }}" rel=prefetch><link href="{{ url_for('static', filename='js/chunk-2d0bdcd1.55481e55.js') }}" rel=prefetch><link href="{{ url_for('static', filename='js/chunk-2d0be185.00266185.js') }}" rel=prefetch><link href="{{ url_for('static', filename='js/chunk-2d0c0e14.acc4673f.js') }}" rel=prefetch><link href="{{ url_for('static', filename='js/chunk-2d0c0e34.e84ea9c9.js') }}" rel=prefetch><link href="{{ url_for('static', filename='js/chunk-2d0c1eac.a51c9c35.js') }}" rel=prefetch><link href="{{ url_for('static', filename='js/chunk-2d0c4293.191e4114.js') }}" rel=prefetch><link href="{{ url_for('static', filename='js/chunk-2d0c46f2.af0f61ee.js') }}" rel=prefetch><link href="{{ url_for('static', filename='js/chunk-2d0c5236.a475074d.js') }}" rel=prefetch><link href="{{ url_for('static', filename='js/chunk-2d0c8085.d15da5e7.js') }}" rel=prefetch><link href="{{ url_for('static', filename='js/chunk-2d0c8691.47a59364.js') }}" rel=prefetch><link href="{{ url_for('static', filename='js/chunk-2d0cc057.0035100b.js') }}" rel=prefetch><link href="{{ url_for('static', filename='js/chunk-2d0cf123.4a1bea35.js') }}" rel=prefetch><link href="{{ url_for('static', filename='js/chunk-2d0cf8b4.13da3415.js') }}" rel=prefetch><link href="{{ url_for('static', filename='js/chunk-2d0cfa98.61669a6e.js') }}" rel=prefetch><link href="{{ url_for('static', filename='js/chunk-2d0d0446.f3f6d505.js') }}" rel=prefetch><link href="{{ url_for('static', filename='js/chunk-2d0d3720.ce5217b2.js') }}" rel=prefetch><link href="{{ url_for('static', filename='js/chunk-2d0d43e7.a2bf52af.js') }}" rel=prefetch><link href="{{ url_for('static', filename='js/chunk-2d0d5c99.27a8d533.js') }}" rel=prefetch><link href="{{ url_for('static', filename='js/chunk-2d0d620f.7bb30ed4.js') }}" rel=prefetch><link href="{{ url_for('static', filename='js/chunk-2d0d6b33.6c0f5622.js') }}" rel=prefetch><link href="{{ url_for('static', filename='js/chunk-2d0d6b45.c988aa9e.js') }}" rel=prefetch><link href="{{ url_for('static', filename='js/chunk-2d0d7279.6c748e44.js') }}" rel=prefetch><link href="{{ url_for('static', filename='js/chunk-2d0de6a9.7717cba2.js') }}" rel=prefetch><link href="{{ url_for('static', filename='js/chunk-2d0de70f.4ddd4a46.js') }}" rel=prefetch><link href="{{ url_for('static', filename='js/chunk-2d0e235d.0e267c38.js') }}" rel=prefetch><link href="{{ url_for('static', filename='js/chunk-2d0e26e8.d50fed6a.js') }}" rel=prefetch><link href="{{ url_for('static', filename='js/chunk-2d0e2cb6.a846eb86.js') }}" rel=prefetch><link href="{{ url_for('static', filename='js/chunk-2d0e48ee.d9d14a00.js') }}" rel=prefetch><link href="{{ url_for('static', filename='js/chunk-2d0e4a7b.e6023d22.js') }}" rel=prefetch><link href="{{ url_for('static', filename='js/chunk-2d0e64c6.948e8e65.js') }}" rel=prefetch><link href="{{ url_for('static', filename='js/chunk-2d0e9011.48280a0a.js') }}" rel=prefetch><link href="{{ url_for('static', filename='js/chunk-2d0e903c.f95c33a6.js') }}" rel=prefetch><link href="{{ url_for('static', filename='js/chunk-2d0f0d79.aba1469a.js') }}" rel=prefetch><link href="{{ url_for('static', filename='js/chunk-2d0f0f77.71058055.js') }}" rel=prefetch><link href="{{ url_for('static', filename='js/chunk-2d208dee.74328e82.js') }}" rel=prefetch><link href="{{ url_for('static', filename='js/chunk-2d208fef.095b556e.js') }}" rel=prefetch><link href="{{ url_for('static', filename='js/chunk-2d2091c9.7c30e42f.js') }}" rel=prefetch><link href="{{ url_for('static', filename='js/chunk-2d20923b.113569e0.js') }}" rel=prefetch><link href="{{ url_for('static', filename='js/chunk-2d2100b7.bbe6fda3.js') }}" rel=prefetch><link href="{{ url_for('static', filename='js/chunk-2d21046a.2674f521.js') }}" rel=prefetch><link href="{{ url_for('static', filename='js/chunk-2d212fc2.90365db6.js') }}" rel=prefetch><link href="{{ url_for('static', filename='js/chunk-2d216052.c04a2c6a.js') }}" rel=prefetch><link href="{{ url_for('static', filename='js/chunk-2d216fc5.97ac244d.js') }}" rel=prefetch><link href="{{ url_for('static', filename='js/chunk-2d2172ec.18a0f907.js') }}" rel=prefetch><link href="{{ url_for('static', filename='js/chunk-2d21a461.4a2b976f.js') }}" rel=prefetch><link href="{{ url_for('static', filename='js/chunk-2d21d862.b29e74b0.js') }}" rel=prefetch><link href="{{ url_for('static', filename='js/chunk-2d221834.19276a1e.js') }}" rel=prefetch><link href="{{ url_for('static', filename='js/chunk-2d221dd6.9a597c4c.js') }}" rel=prefetch><link href="{{ url_for('static', filename='js/chunk-2d221e25.02b6512e.js') }}" rel=prefetch><link href="{{ url_for('static', filename='js/chunk-2d225244.62eef143.js') }}" rel=prefetch><link href="{{ url_for('static', filename='js/chunk-2d2255fa.04ed99ec.js') }}" rel=prefetch><link href="{{ url_for('static', filename='js/chunk-2d225dc7.e5c474e4.js') }}" rel=prefetch><link href="{{ url_for('static', filename='js/chunk-2d228e9f.71c9b3f6.js') }}" rel=prefetch><link href="{{ url_for('static', filename='js/chunk-2d22c8dd.dd9fb946.js') }}" rel=prefetch><link href="{{ url_for('static', filename='js/chunk-2d230ab1.008ff684.js') }}" rel=prefetch><link href="{{ url_for('static', filename='js/chunk-2d23720c.404415ee.js') }}" rel=prefetch><link href="{{ url_for('static', filename='js/chunk-2d23778d.d01e3efc.js') }}" rel=prefetch><link href="{{ url_for('static', filename='js/chunk-324a8daa.5b3048f9.js') }}" rel=prefetch><link href="{{ url_for('static', filename='js/chunk-3575b4ce.1dbf3660.js') }}" rel=prefetch><link href="{{ url_for('static', filename='js/chunk-3e925ec6.719a6ede.js') }}" rel=prefetch><link href="{{ url_for('static', filename='js/chunk-3ef5cf24.9386b48f.js') }}" rel=prefetch><link href="{{ url_for('static', filename='js/chunk-44b2f8f8.4dbcca7a.js') }}" rel=prefetch><link href="{{ url_for('static', filename='js/chunk-5343f65a.dc04e31f.js') }}" rel=prefetch><link href="{{ url_for('static', filename='js/chunk-55b461e0.1d060566.js') }}" rel=prefetch><link href="{{ url_for('static', filename='js/chunk-5789dc8a.a125803c.js') }}" rel=prefetch><link href="{{ url_for('static', filename='js/chunk-5cf56edd.f58f770c.js') }}" rel=prefetch><link href="{{ url_for('static', filename='js/chunk-5f5b5007.80256587.js') }}" rel=prefetch><link href="{{ url_for('static', filename='js/chunk-6146d972.acdff256.js') }}" rel=prefetch><link href="{{ url_for('static', filename='js/chunk-63d5030c.ff3c90a9.js') }}" rel=prefetch><link href="{{ url_for('static', filename='js/chunk-66551290.69c60fe6.js') }}" rel=prefetch><link href="{{ url_for('static', filename='js/chunk-69eca88c.b2d57f19.js') }}" rel=prefetch><link href="{{ url_for('static', filename='js/chunk-6f24c2c8.8bb77c3f.js') }}" rel=prefetch><link href="{{ url_for('static', filename='js/chunk-6f2a5820.e97ff0be.js') }}" rel=prefetch><link href="{{ url_for('static', filename='js/chunk-707eb013.d27eb856.js') }}" rel=prefetch><link href="{{ url_for('static', filename='js/chunk-721c801f.c8a2e40e.js') }}" rel=prefetch><link href="{{ url_for('static', filename='js/chunk-83c74884.a49edad1.js') }}" rel=prefetch><link href="{{ url_for('static', filename='js/chunk-896eee8c.5be090f2.js') }}" rel=prefetch><link href="{{ url_for('static', filename='js/chunk-a6604a3e.5696003a.js') }}" rel=prefetch><link href="{{ url_for('static', filename='js/chunk-ab01839c.1b393093.js') }}" rel=prefetch><link href="{{ url_for('static', filename='js/chunk-abafcd8e.f757f722.js') }}" rel=prefetch><link href="{{ url_for('static', filename='js/chunk-ae49e65e.3c1f8417.js') }}" rel=prefetch><link href="{{ url_for('static', filename='js/chunk-b441fb64.e1796136.js') }}" rel=prefetch><link href="{{ url_for('static', filename='js/chunk-ba7886f2.ee836f2f.js') }}" rel=prefetch><link href="{{ url_for('static', filename='js/chunk-cab13e3c.3b9d7679.js') }}" rel=prefetch><link href="{{ url_for('static', filename='js/chunk-cb1baf7a.5aa08c2f.js') }}" rel=prefetch><link href="{{ url_for('static', filename='js/chunk-cbe61776.1824b04d.js') }}" rel=prefetch><link href="{{ url_for('static', filename='js/chunk-d8fb7f32.949e892c.js') }}" rel=prefetch><link href="{{ url_for('static', filename='js/chunk-e6edb01a.8ee9cd22.js') }}" rel=prefetch><link href="{{ url_for('static', filename='js/chunk-f0abf240.aedef381.js') }}" rel=prefetch><link href="{{ url_for('static', filename='js/chunk-fedbce3e.6bb3c0e7.js') }}" rel=prefetch><link href="{{ url_for('static', filename='css/app.39efe745.css') }}" rel=preload as=style><link href="{{ url_for('static', filename='css/chunk-vendors.2f883a2c.css') }}" rel=preload as=style><link href="{{ url_for('static', filename='js/app.05cabaa7.js') }}" rel=preload as=script><link href="{{ url_for('static', filename='js/chunk-vendors.ec1cb3eb.js') }}" rel=preload as=script><link href="{{ url_for('static', filename='css/chunk-vendors.2f883a2c.css') }}" rel=stylesheet><link href="{{ url_for('static', filename='css/app.39efe745.css') }}" rel=stylesheet></head><body><div id=app></div><script src="{{ url_for('static', filename='js/chunk-vendors.ec1cb3eb.js') }}"></script><script src="{{ url_for('static', filename='js/app.05cabaa7.js') }}"></script></body></html>