.splitter-pane-resizer[data-v-09c2e5ce]{-webkit-box-sizing:border-box;box-sizing:border-box;background:#000;position:absolute;opacity:.2;z-index:1;background-clip:padding-box}.splitter-pane-resizer.horizontal[data-v-09c2e5ce]{height:11px;margin:-5px 0;border-top:5px solid hsla(0,0%,100%,0);border-bottom:5px solid hsla(0,0%,100%,0);cursor:row-resize;width:100%}.splitter-pane-resizer.vertical[data-v-09c2e5ce]{width:11px;height:100%;margin-left:-5px;border-left:5px solid hsla(0,0%,100%,0);border-right:5px solid hsla(0,0%,100%,0);cursor:col-resize}.splitter-pane.vertical.splitter-paneL[data-v-f23ea7c6]{position:absolute;left:0;height:100%}.splitter-pane.vertical.splitter-paneR[data-v-f23ea7c6]{position:absolute;right:0;height:100%}.splitter-pane.horizontal.splitter-paneL[data-v-f23ea7c6]{position:absolute;top:0;width:100%}.splitter-pane.horizontal.splitter-paneR[data-v-f23ea7c6]{position:absolute;bottom:0;width:100%;padding-top:3px}.clearfix[data-v-0bf3d118]:after{visibility:hidden;display:block;font-size:0;content:" ";clear:both;height:0}.vue-splitter-container[data-v-0bf3d118]{height:100%;position:relative}.ide-bottom-bar[data-v-3f09efd1]{width:100vw;height:3vh;padding-right:16px;color:#fff}.ide-bottom-bar-left[data-v-3f09efd1]{width:95vw;padding-left:8px}.ide-bottom-bar-right[data-v-3f09efd1]{width:5vw}.info[data-v-3f09efd1]{padding:auto 0;margin-left:12px;font-size:16px;color:#fff}.left-pane[data-v-249aa1a4]{background:#333!important;height:97vh;max-width:72px;min-width:72px;padding:0}.icon-button[data-v-249aa1a4]{margin:10px}.file-list{background:#252526!important;padding:0}.file-list,.tree{width:100%;height:100%}.tree-node-label{margin-left:6px;font-size:18px;color:#e0e0e0}.tree-node{width:100%;height:24px}.tree-node-left{width:20%}.tree-node-right{width:75%}.content,.outer-container{width:100%;height:97vh}.outer-container{width:100%;height:100%;position:relative;overflow:hidden}.inner-container{width:300%;height:100%;position:absolute;left:0;overflow-x:hidden;overflow-y:scroll}.el-tree{position:relative;cursor:default;background:#252526!important;color:rgba(221,207,207,.67)!important}.el-tree-node__label{font-size:18px!important}.el-tree-node__content{display:-webkit-box;display:-ms-flexbox;display:flex;-webkit-box-align:center;-ms-flex-align:center;align-items:center;height:32px!important;cursor:pointer}.el-tree--highlight-current .el-tree-node.is-current>.el-tree-node__content,.el-tree-node__content:hover{background-color:#37373d!important}.el-tree-node:focus>.el-tree-node__content{background-color:#37373d}.el-tree-node__expand-icon{cursor:pointer;color:#c0c4cc;font-size:16px;-webkit-transform:rotate(0);transform:rotate(0);-webkit-transition:-webkit-transform .3s ease-in-out;transition:transform .3s ease-in-out,-webkit-transform .3s ease-in-out}.el-upload-dragger{background-color:#212121!important;border:1px #d9d9d9;border-radius:6px;-webkit-box-sizing:border-box;box-sizing:border-box;width:300px;height:180px;text-align:center;position:relative;overflow:hidden;margin-top:32px}.monaco-editor-container[data-v-9f868d2e]{min-height:350px;height:100%;width:100%}.editor-tabs[data-v-9f868d2e]{height:48px;width:100%;background:#252526;position:fixed;line-height:48px;padding:0 12px}.editor-tabs-flex[data-v-9f868d2e]{width:50%;height:100%}.monaco-editor[data-v-9f868d2e]{min-height:350px;height:100%;width:100%;margin-top:48px}.editor-tabs-title[data-v-9f868d2e]{font-size:16px!important;color:#e0e0e0;margin-left:6px}.bg[data-v-56a90753]{background:#1e1e1e;width:100%;position:relative}.progress-bar[data-v-56a90753]{position:fixed;width:100vw;z-index:999}.pane-layout[data-v-56a90753]{width:calc(100% - 70px);max-width:calc(100% - 70px);height:97vh;max-height:97vh}.left-pane[data-v-56a90753]{padding:0;overflow:hidden;background:#252526!important;min-width:0;width:20%;max-width:40%;height:100%}.subpane-layout[data-v-56a90753]{width:80%;min-width:60%;height:100%;border-left:2px solid rgba(97,97,97,.38)}.editor[data-v-56a90753],.terminal-container[data-v-56a90753]{background:#1e1e1e;width:100%;height:100%}.terminal-container[data-v-56a90753]{border-top:2px solid rgba(97,97,97,.38);-webkit-box-flex:1;-ms-flex-positive:1;flex-grow:1;min-height:0;overflow:hidden;padding-top:15px;padding-left:15px;padding-right:0;padding-bottom:15px}