.el-upload-dragger{background-color:#212121!important;border:1px #d9d9d9;border-radius:6px;-webkit-box-sizing:border-box;box-sizing:border-box;width:300px;height:180px;text-align:center;position:relative;overflow:hidden;margin-top:32px}