.file-list{background:#252526!important;padding:0}.file-list,.tree{width:100%;height:100%}.tree-node-label{margin-left:6px;font-size:18px;color:#e0e0e0}.tree-node{width:100%;height:24px}.tree-node-left{width:20%}.tree-node-right{width:75%}.content,.outer-container{width:100%;height:97vh}.outer-container{width:100%;height:100%;position:relative;overflow:hidden}.inner-container{width:300%;height:100%;position:absolute;left:0;overflow-x:hidden;overflow-y:scroll}.el-tree{position:relative;cursor:default;background:#252526!important;color:rgba(221,207,207,.67)!important}.el-tree-node__label{font-size:18px!important}.el-tree-node__content{display:-webkit-box;display:-ms-flexbox;display:flex;-webkit-box-align:center;-ms-flex-align:center;align-items:center;height:32px!important;cursor:pointer}.el-tree--highlight-current .el-tree-node.is-current>.el-tree-node__content,.el-tree-node__content:hover{background-color:#37373d!important}.el-tree-node:focus>.el-tree-node__content{background-color:#37373d}.el-tree-node__expand-icon{cursor:pointer;color:#c0c4cc;font-size:16px;-webkit-transform:rotate(0);transform:rotate(0);-webkit-transition:-webkit-transform .3s ease-in-out;transition:transform .3s ease-in-out,-webkit-transform .3s ease-in-out}