(window["webpackJsonp"]=window["webpackJsonp"]||[]).push([["chunk-2d0c46f2"],{"3b8e":function(t,i,e){"use strict";e.r(i);var s={methods:{slotNextFile:function(){this.index+=1,this.index<=this.putFileData.length-1?this.$send(this.SIGNAL_PUT_FILE(this)):(this.index=0,this.putFileData=[],this.putFileName=[],this.$refs["eluploader"].clearFiles())}}};i["default"]=s}}]);
//# sourceMappingURL=chunk-2d0c46f2.af0f61ee.js.map