.splitter-pane.vertical.splitter-paneL[data-v-f23ea7c6]{position:absolute;left:0;height:100%}.splitter-pane.vertical.splitter-paneR[data-v-f23ea7c6]{position:absolute;right:0;height:100%}.splitter-pane.horizontal.splitter-paneL[data-v-f23ea7c6]{position:absolute;top:0;width:100%}.splitter-pane.horizontal.splitter-paneR[data-v-f23ea7c6]{position:absolute;bottom:0;width:100%;padding-top:3px}