(window["webpackJsonp"]=window["webpackJsonp"]||[]).push([["chunk-83c74884"],{"158a":function(n,t,i){"use strict";i.r(t);i("cf54");var s={watch:{listener:function(){if(this.signals.ref===this.$options.name)try{this[this.signals.slot](this.signals.kwargs)}catch(n){console.log(n)}}}};t["default"]=s},cf54:function(n,t,i){var s=i("9a0d").f,c=Function.prototype,o=/^\s*function ([^ (]*)/,a="name";a in c||i("f711")&&s(c,a,{configurable:!0,get:function(){try{return(""+this).match(o)[1]}catch(n){return""}}})}}]);
//# sourceMappingURL=chunk-83c74884.a49edad1.js.map