(window["webpackJsonp"]=window["webpackJsonp"]||[]).push([["chunk-2d2100b7"],{b5e3:function(t,n,o){"use strict";o.r(n);var s={methods:{slotConnected:function(){this.connected=!0},slotDisconnected:function(){this.connected=!1},slotShowMemoryStatus:function(t){this.memoryStatus=t.data},slotShowSysInfo:function(t){this.sysInfo=t.data}}};n["default"]=s}}]);
//# sourceMappingURL=chunk-2d2100b7.bbe6fda3.js.map