(window["webpackJsonp"]=window["webpackJsonp"]||[]).push([["chunk-2d0d6b33"],{7455:function(e,t,n){"use strict";n.r(t);var o={methods:{SIGNAL_CONNECT_TO_DEVICE:function(e){var t=arguments.length>1&&void 0!==arguments[1]?arguments[1]:"cli",n=arguments.length>2&&void 0!==arguments[2]?arguments[2]:"slotConnectToDevice";return{event:"connectToDevice",sender:e,receiver:t,slot:n,kwargs:{url:this.url,passwd:this.passwd}}},SIGNAL_DISCONNECT:function(e){var t=arguments.length>1&&void 0!==arguments[1]?arguments[1]:"cli",n=arguments.length>2&&void 0!==arguments[2]?arguments[2]:"slotDisconnect";return{event:"disconnect",sender:e,receiver:t,slot:n,kwargs:{}}},SIGNAL_TOGGLE_SETTINGS:function(e){var t=arguments.length>1&&void 0!==arguments[1]?arguments[1]:"parent",n=arguments.length>2&&void 0!==arguments[2]?arguments[2]:"slotToggleSettings";return{event:"toggleSettings",sender:e,receiver:t,slot:n,kwargs:{}}},SIGNAL_APPLY_FONTSIZE:function(e){var t=arguments.length>1&&void 0!==arguments[1]?arguments[1]:"editor",n=arguments.length>2&&void 0!==arguments[2]?arguments[2]:"slotApplyFontSize";return{event:"applyFontSize",sender:e,receiver:t,slot:n,kwargs:{fontSize:this.fontSize}}}}};t["default"]=o}}]);
//# sourceMappingURL=chunk-2d0d6b33.6c0f5622.js.map