.monaco-editor-container[data-v-9f868d2e]{min-height:350px;height:100%;width:100%}.editor-tabs[data-v-9f868d2e]{height:48px;width:100%;background:#252526;position:fixed;line-height:48px;padding:0 12px}.editor-tabs-flex[data-v-9f868d2e]{width:50%;height:100%}.monaco-editor[data-v-9f868d2e]{min-height:350px;height:100%;width:100%;margin-top:48px}.editor-tabs-title[data-v-9f868d2e]{font-size:16px!important;color:#e0e0e0;margin-left:6px}